create sequence tci_seq start 1;
create table DEMOGRAPHIC (
  PATID varchar(800),
  BIRTH_DATE date,
  BIRTH_TIME varchar(5),
  SEX varchar(2),
  SEXUAL_ORIENTATION varchar(2),
  GENDER_IDENTITY varchar(2),
  HISPANIC varchar(2),
  RACE varchar(2),
  BIOBANK_FLAG varchar(1),
  PAT_PREF_LANGUAGE_SPOKEN varchar(3),
  RAW_SEX varchar(800),
  RAW_SEXUAL_ORIENTATION varchar(800),
  RAW_GENDER_IDENTITY varchar(800),
  RAW_HISPANIC varchar(800),
  RAW_RACE varchar(800),
  RAW_PAT_PREF_LANGUAGE_SPOKEN varchar(800)
);

create table ENCOUNTER (
  ENCOUNTERID varchar(800),
  PATID varchar(800),
  ADMIT_DATE date,
  ADMIT_TIME varchar(5),
  DISCHARGE_DATE date,
  DISCHARGE_TIME varchar(5),
  FACILITY_LOCATION varchar(3),
  ENC_TYPE varchar(2),
  FACILITYID varchar(800),
  DISCHARGE_DISPOSITION varchar(2),
  DISCHARGE_STATUS varchar(2),
  DRG varchar(3),
  DRG_TYPE varchar(2),
  ADMITTING_SOURCE varchar(2),
  PAYER_TYPE_PRIMARY varchar(5) ,
  PAYER_TYPE_SECONDARY varchar(5),
  FACILITY_TYPE varchar(800),
  RAW_SITEID varchar(800),
  RAW_ENC_TYPE varchar(800),
  RAW_DISCHARGE_DISPOSITION varchar(800),
  RAW_DISCHARGE_STATUS varchar(800),
  RAW_DRG_TYPE varchar(800),
  RAW_ADMITTING_SOURCE varchar(800),
  RAW_FACILITY_TYPE varchar(800),
  RAW_PAYER_TYPE_PRIMARY varchar(800),
  RAW_PAYER_NAME_PRIMARY varchar(800),
  RAW_PAYER_ID_PRIMARY varchar(800),
  RAW_PAYER_TYPE_SECONDARY varchar(800),
  RAW_PAYER_NAME_SECONDARY varchar(800),
  RAW_PAYER_ID_SECONDARY varchar(800)
);

create table ENROLLMENT (
  PATID varchar(800),
  ENR_START_DATE date,
  ENR_END_DATE date,
  CHART varchar(1),
  ENR_BASIS varchar(1)
);

create table DIAGNOSIS (
  DIAGNOSISID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  ENC_TYPE varchar(2),
  ADMIT_DATE date,
  DX varchar(18),
  DX_TYPE varchar(2),
  DX_SOURCE varchar(2),
  DX_ORIGIN varchar(2),
  PDX varchar(2),
  DX_POA varchar(2),
  RAW_DX varchar(800),
  RAW_DX_TYPE varchar(800),
  RAW_DX_SOURCE varchar(800),
  RAW_PDX varchar(800),
  RAW_DX_POA varchar(800)
);

create table PROCEDURES (
  PROCEDURESID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  ENC_TYPE varchar(2),
  ADMIT_DATE date,
  PX_DATE date,
  PX varchar(11),
  PX_TYPE varchar(2),
  PX_SOURCE varchar(2),
  PPX varchar(2),
  RAW_PX varchar(800),
  RAW_PX_TYPE varchar(800),
  RAW_PPX varchar(800)
);

create table VITAL (
  VITALID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  MEASURE_DATE date,
  MEASURE_TIME varchar(5),
  VITAL_SOURCE varchar(2),
  HT float,
  WT float,
  DIASTOLIC float,
  SYSTOLIC float,
  ORIGINAL_BMI float,
  BP_POSITION varchar(2),
  SMOKING varchar(2),
  TOBACCO varchar(2),
  TOBACCO_TYPE varchar(2),
  RAW_DIASTOLIC varchar(800),
  RAW_SYSTOLIC varchar(800),
  RAW_BP_POSITION varchar(800),
  RAW_SMOKING varchar(800),
  RAW_TOBACCO varchar(800),
  RAW_TOBACCO_TYPE varchar(800)
);

create table PRESCRIBING (
  PRESCRIBINGID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  RX_ORDER_DATE date,
  RX_ORDER_TIME varchar(5),
  RX_START_DATE date,
  RX_END_DATE date,
  RX_DOSE_ORDERED float,
  RX_DOSE_ORDERED_UNIT varchar(800),
  RX_QUANTITY float,
  RX_DOSE_FORM varchar(800),
  RX_REFILLS float,
  RX_DAYS_SUPPLY float,
  RX_FREQUENCY varchar(2),
  RX_PRN_FLAG varchar(1),
  RX_ROUTE varchar(800),
  RX_BASIS varchar(2),
  RXNORM_CUI varchar (8),
  RX_SOURCE varchar(2),
  RX_DISPENSE_AS_WRITTEN varchar(2),
  RAW_RX_MED_NAME varchar(800),
  RAW_RX_FREQUENCY varchar(800),
  RAW_RXNORM_CUI varchar(800),
  RAW_RX_QUANTITY varchar(800),
  RAW_RX_NDC varchar(800),
  RAW_RX_DOSE_ORDERED varchar(800),
  RAW_RX_DOSE_ORDERED_UNIT varchar(800),
  RAW_RX_ROUTE varchar(800),
  RAW_RX_REFILLS varchar(800)
);

create table DISPENSING (
  DISPENSINGID varchar(800),
  PATID varchar(800),
  PRESCRIBINGID varchar(800),
  DISPENSE_DATE date,
  NDC varchar(11),
  DISPENSE_SUP float,
  DISPENSE_AMT float,
  DISPENSE_DOSE_DISP float,
  DISPENSE_DOSE_DISP_UNIT varchar(800),
  DISPENSE_ROUTE varchar(800),
  RAW_NDC varchar(800),
  RAW_DISPENSE_DOSE_DISP varchar(800),
  RAW_DISPENSE_DOSE_DISP_UNIT varchar(800),
  RAW_DISPENSE_ROUTE varchar(800)
);

create table LAB_RESULT_CM (
  LAB_RESULT_CM_ID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  SPECIMEN_SOURCE varchar(800),
  LAB_LOINC varchar(10),
  PRIORITY varchar(2),
  RESULT_LOC varchar(2),
  LAB_PX varchar(11),
  LAB_PX_TYPE varchar(2),
  LAB_ORDER_DATE date,
  SPECIMEN_DATE date,
  SPECIMEN_TIME varchar(5),
  RESULT_DATE date,
  RESULT_TIME varchar(5),
  RESULT_QUAL varchar(800),
  RESULT_SNOMED varchar(800),
  RESULT_NUM float,
  RESULT_MODIFIER varchar(2),
  RESULT_UNIT varchar(800),
  NORM_RANGE_LOW varchar(10),
  NORM_MODIFIER_LOW varchar(2),
  NORM_RANGE_HIGH varchar(10),
  NORM_MODIFIER_HIGH varchar(2),
  ABN_IND varchar(2),
  RAW_LAB_NAME varchar(800),
  RAW_LAB_CODE varchar(800),
  RAW_PANEL varchar(800),
  RAW_RESULT varchar(800),
  RAW_UNIT varchar(800),
  RAW_ORDER_DEPT varchar(800),
  RAW_FACILITY_CODE varchar(800)
);

create table CONDITION (
  CONDITIONID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  REPORT_DATE date,
  RESOLVE_DATE date,
  ONSET_DATE date,
  CONDITION_STATUS varchar(2),
  CONDITION varchar(18),
  CONDITION_TYPE varchar(2),
  CONDITION_SOURCE varchar(2),
  RAW_CONDITION_STATUS varchar(800),
  RAW_CONDITION varchar(800),
  RAW_CONDITION_TYPE varchar(800),
  RAW_CONDITION_SOURCE varchar(800)
);

create table PRO_CM (
  PRO_CM_ID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  PRO_DATE date,
  PRO_TIME varchar(5),
  PRO_TYPE varchar(2),
  PRO_ITEM_NAME varchar(800),
  PRO_ITEM_LOINC varchar(10),
  PRO_RESPONSE_TEXT varchar(800),
  PRO_RESPONSE_NUM float,
  PRO_METHOD varchar(2),
  PRO_MODE varchar(2),
  PRO_CAT varchar(2),
  PRO_ITEM_VERSION varchar(800),
  PRO_MEASURE_NAME varchar(800),
  PRO_MEASURE_SEQ varchar(800),
  PRO_MEASURE_SCORE float,
  PRO_MEASURE_THETA float,
  PRO_MEASURE_SCALED_TSCORE float,
  PRO_MEASURE_STANDARD_ERROR float,
  PRO_MEASURE_COUNT_SCORED float,
  PRO_MEASURE_LOINC varchar(10),
  PRO_MEASURE_VERSION varchar(800),
  PRO_ITEM_FULLNAME varchar(800),
  PRO_ITEM_TEXT varchar(800),
  PRO_MEASURE_FULLNAME varchar(800)
);

create table PCORNET_TRIAL (
  PATID varchar(800),
  TRIALID varchar(20),
  PARTICIPANTID varchar(800),
  TRIAL_SITEID varchar(800),
  TRIAL_ENROLL_DATE date,
  TRIAL_END_DATE date,
  TRIAL_WITHDRAW_DATE date,
  TRIAL_INVITE_CODE varchar(20)
);

create table DEATH (
  PATID varchar(800),
  DEATH_DATE date,
  DEATH_DATE_IMPUTE varchar(2),
  DEATH_SOURCE varchar(2),
  DEATH_MATCH_CONFIDENCE varchar(2)
);

create table DEATH_CAUSE (
  PATID varchar(800),
  DEATH_CAUSE varchar(8),
  DEATH_CAUSE_CODE varchar(2),
  DEATH_CAUSE_TYPE varchar(2),
  DEATH_CAUSE_SOURCE varchar(2),
  DEATH_CAUSE_CONFIDENCE varchar(2)
);

create table MED_ADMIN (
  MEDADMINID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  PRESCRIBINGID varchar(800),
  MEDADMIN_START_DATE date,
  MEDADMIN_START_TIME varchar(5),
  MEDADMIN_STOP_DATE date,
  MEDADMIN_STOP_TIME varchar(5),
  MEDADMIN_TYPE varchar(2),
  MEDADMIN_CODE varchar(800),
  MEDADMIN_DOSE_ADMIN float,
  MEDADMIN_DOSE_ADMIN_UNIT varchar(800),
  MEDADMIN_ROUTE varchar(800),
  MEDADMIN_SOURCE varchar(2),
  RAW_MEDADMIN_MED_NAME varchar(800),
  RAW_MEDADMIN_CODE varchar(800),
  RAW_MEDADMIN_DOSE_ADMIN varchar(800),
  RAW_MEDADMIN_DOSE_ADMIN_UNIT varchar(800),
  RAW_MEDADMIN_ROUTE varchar(800)
);

create table OBS_CLIN (
  OBSCLINID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  OBSCLIN_DATE date,
  OBSCLIN_TIME varchar(5) ,
  OBSCLIN_TYPE varchar(2),
  OBSCLIN_CODE varchar(800),
  OBSCLIN_RESULT_QUAL varchar(800),
  OBSCLIN_RESULT_TEXT varchar(800),
  OBSCLIN_RESULT_SNOMED varchar(800),
  OBSCLIN_RESULT_NUM float,
  OBSCLIN_RESULT_MODIFIER varchar(2),
  OBSCLIN_RESULT_UNIT varchar(800),
  RAW_OBSCLIN_NAME varchar(800),
  RAW_OBSCLIN_CODE varchar(800),
  RAW_OBSCLIN_TYPE varchar(800),
  RAW_OBSCLIN_RESULT varchar(800),
  RAW_OBSCLIN_MODIFIER varchar(800),
  RAW_OBSCLIN_UNIT varchar(800)
);

create table OBS_GEN (
  OBSGENID varchar(800),
  PATID varchar(800),
  ENCOUNTERID varchar(800),
  OBSGEN_DATE date,
  OBSGEN_TIME varchar(5) ,
  OBSGEN_TYPE varchar(30),
  OBSGEN_CODE varchar(800),
  OBSGEN_RESULT_QUAL varchar(800),
  OBSGEN_RESULT_TEXT varchar(800),
  OBSGEN_RESULT_NUM float,
  OBSGEN_RESULT_MODIFIER varchar(2),
  OBSGEN_RESULT_UNIT varchar(800),
  OBSGEN_TABLE_MODIFIED varchar(3),
  OBSGEN_ID_MODIFIED varchar(800),
  RAW_OBSGEN_NAME varchar(800),
  RAW_OBSGEN_CODE varchar(800),
  RAW_OBSGEN_TYPE varchar(800),
  RAW_OBSGEN_RESULT varchar(800),
  RAW_OBSGEN_UNIT varchar(800)
);

create table HARVEST (
  NETWORKID varchar(10),
  NETWORK_NAME varchar(20),
  DATAMARTID varchar(10),
  DATAMART_NAME varchar(20),
  DATAMART_PLATFORM varchar(2),
  CDM_VERSION float,
  DATAMART_CLAIMS varchar(2),
  DATAMART_EHR varchar(2),
  BIRTH_DATE_MGMT varchar(2),
  ENR_START_DATE_MGMT varchar(2),
  ENR_END_DATE_MGMT varchar(2),
  ADMIT_DATE_MGMT varchar(2),
  DISCHARGE_DATE_MGMT varchar(2),
  PX_DATE_MGMT varchar(2),
  RX_ORDER_DATE_MGMT varchar(2),
  RX_START_DATE_MGMT varchar(2),
  RX_END_DATE_MGMT varchar(2),
  DISPENSE_DATE_MGMT varchar(2),
  LAB_ORDER_DATE_MGMT varchar(2),
  SPECIMEN_DATE_MGMT varchar(2),
  RESULT_DATE_MGMT varchar(2),
  MEASURE_DATE_MGMT varchar(2),
  ONSET_DATE_MGMT varchar(2),
  REPORT_DATE_MGMT varchar(2),
  RESOLVE_DATE_MGMT varchar(2),
  PRO_DATE_MGMT varchar(2),
  DEATH_DATE_MGMT varchar(2),
  MEDADMIN_START_DATE_MGMT varchar(2),
  MEDADMIN_STOP_DATE_MGMT varchar(2),
  OBSCLIN_DATE_MGMT varchar(2),
  OBSGEN_DATE_MGMT varchar(2),
  REFRESH_DEMOGRAPHIC_DATE date,
  REFRESH_ENROLLMENT_DATE date,
  REFRESH_ENCOUNTER_DATE date,
  REFRESH_DIAGNOSIS_DATE date,
  REFRESH_PROCEDURES_DATE date,
  REFRESH_VITAL_DATE date,
  REFRESH_DISPENSING_DATE date,
  REFRESH_LAB_RESULT_CM_DATE date,
  REFRESH_CONDITION_DATE date,
  REFRESH_PRO_CM_DATE date,
  REFRESH_PRESCRIBING_DATE date,
  REFRESH_PCORNET_TRIAL_DATE date,
  REFRESH_DEATH_DATE date,
  REFRESH_DEATH_CAUSE_DATE date,
  REFRESH_MED_ADMIN_DATE date,
  REFRESH_OBS_CLIN_DATE date,
  REFRESH_OBS_GEN_DATE date
);


-- Constraints
alter table ENCOUNTER alter column PATID set not null;
alter table ENCOUNTER alter column ADMIT_DATE set not null;
alter table ENCOUNTER alter column ENC_TYPE set not null;
alter table ENROLLMENT alter column PATID set not null;
alter table ENROLLMENT alter column ENR_START_DATE set not null;
alter table ENROLLMENT alter column ENR_BASIS set not null;
alter table DIAGNOSIS alter column PATID set not null;
alter table DIAGNOSIS alter column DX set not null;
alter table DIAGNOSIS alter column DX_TYPE set not null;
alter table DIAGNOSIS alter column DX_SOURCE set not null;
alter table PROCEDURES alter column PATID set not null;
alter table PROCEDURES alter column PX set not null;
alter table PROCEDURES alter column PX_TYPE set not null;
alter table VITAL alter column PATID set not null;
alter table VITAL alter column MEASURE_DATE set not null;
alter table VITAL alter column VITAL_SOURCE set not null;
alter table PRESCRIBING alter column PATID set not null;
alter table DISPENSING alter column PATID set not null;
alter table DISPENSING alter column DISPENSE_DATE set not null;
alter table DISPENSING alter column NDC set not null;
alter table LAB_RESULT_CM alter column PATID set not null;
alter table LAB_RESULT_CM alter column RESULT_DATE set not null;
alter table CONDITION alter column PATID set not null;
alter table CONDITION alter column CONDITION set not null;
alter table CONDITION alter column CONDITION_TYPE set not null;
alter table CONDITION alter column CONDITION_SOURCE set not null;
alter table PRO_CM alter column PATID set not null;
alter table PRO_CM alter column PRO_DATE set not null;
alter table PCORNET_TRIAL alter column PATID set not null;
alter table PCORNET_TRIAL alter column TRIALID set not null;
alter table PCORNET_TRIAL alter column PARTICIPANTID set not null;
alter table DEATH alter column PATID set not null;
alter table DEATH alter column DEATH_SOURCE set not null;
alter table DEATH_CAUSE alter column PATID set not null;
alter table DEATH_CAUSE alter column DEATH_CAUSE set not null;
alter table DEATH_CAUSE alter column DEATH_CAUSE_CODE set not null;
alter table DEATH_CAUSE alter column DEATH_CAUSE_TYPE set not null;
alter table DEATH_CAUSE alter column DEATH_CAUSE_SOURCE set not null;
alter table MED_ADMIN alter column PATID set not null;
alter table MED_ADMIN alter column MEDADMIN_START_DATE set not null;
alter table OBS_CLIN alter column PATID set not null;
alter table OBS_CLIN alter column OBSCLIN_DATE set not null;
alter table OBS_GEN alter column PATID set not null;
alter table OBS_GEN alter column OBSGEN_DATE set not null;
alter table HARVEST alter column NETWORKID set not null;
alter table HARVEST alter column DATAMARTID set not null;
-- Primary Keys
alter table DEMOGRAPHIC add constraint pkDEMOGRAPHIC primary key (PATID);
alter table ENCOUNTER add constraint pkENCOUNTER primary key (ENCOUNTERID);
alter table DIAGNOSIS add constraint pkDIAGNOSIS primary key (DIAGNOSISID);
alter table PROCEDURES add constraint pkPROCEDURES primary key (PROCEDURESID);
alter table VITAL add constraint pkVITAL primary key (VITALID);
alter table PRESCRIBING add constraint pkPRESCRIBING primary key (PRESCRIBINGID);
alter table DISPENSING add constraint pkDISPENSING primary key (DISPENSINGID);
alter table LAB_RESULT_CM add constraint pkLAB_RESULT_CM primary key (LAB_RESULT_CM_ID);
alter table CONDITION add constraint pkCONDITION primary key (CONDITIONID);
alter table PRO_CM add constraint pkPRO_CM primary key (PRO_CM_ID);
alter table MED_ADMIN add constraint pkMED_ADMIN primary key (MEDADMINID);
alter table OBS_CLIN add constraint pkOBS_CLIN primary key (OBSCLINID);
alter table OBS_GEN add constraint pkOBS_GEN primary key (OBSGENID);

-- Foreign Keys
alter table ENCOUNTER add constraint fk_ENCOUNTER_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table ENROLLMENT add constraint fk_ENROLLMENT_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table DIAGNOSIS add constraint fk_DIAGNOSIS_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table PROCEDURES add constraint fk_PROCEDURES_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table VITAL add constraint fk_VITAL_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table PRESCRIBING add constraint fk_PRESCRIBING_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table DISPENSING add constraint fk_DISPENSING_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table LAB_RESULT_CM add constraint fk_LAB_RESULT_CM_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table CONDITION add constraint fk_CONDITION_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table PRO_CM add constraint fk_PRO_CM_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table PCORNET_TRIAL add constraint fk_PCORNET_TRIAL_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table DEATH add constraint fk_DEATH_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table DEATH_CAUSE add constraint fk_DEATH_CAUSE_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table MED_ADMIN add constraint fk_MED_ADMIN_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table OBS_CLIN add constraint fk_OBS_CLIN_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
alter table OBS_GEN add constraint fk_OBS_GEN_DEMOGRAPHIC foreign key (PATID) references DEMOGRAPHIC (PATID) on update no action on delete no action;
